@@ -52,6 +52,34 @@ test_that("convertGDP replace missing conversion factors", {
   expect_equal(gdp2$iso3c, gdp_conv5$iso3c)
 })
 
+test_that("convertGDP replace_NAs = NA", {
+  # wb_wi does not have info for ABW in 2019
+  gdp <- tidyr::expand_grid("iso3c" = c("ABW", "DEU", "USA"),
+                            "year" = c(2010, 2015, 2025),
+                            "SSP" = c("SSP1", "SSP2"), "value" = 100)
+
+  expect_warning(convertGDP(gdp,
+                            unit_in = "constant 2005 Int$PPP",
+                            unit_out = "constant 2019 US$MER"))
+
+  expect_silent(convertGDP(gdp,
+                           unit_in = "constant 2005 Int$PPP",
+                           unit_out = "constant 2019 US$MER",
+                           replace_NAs = NA))
+
+  gdp_1 <- suppressWarnings(convertGDP(gdp,
+                                       unit_in = "constant 2005 Int$PPP",
+                                       unit_out = "constant 2019 US$MER"))
+
+  gdp_2 <- convertGDP(gdp,
+                      unit_in = "constant 2005 Int$PPP",
+                      unit_out = "constant 2019 US$MER",
+                      replace_NAs = NA)
+
+  expect_equal(gdp_1, gdp_2)
+})
+
+
 test_that("convertGDP replace_NAs = 'no_conversion'", {
   # wb_wi does not have info for ABW in 2019
   gdp <- tidyr::expand_grid("iso3c" = c("ABW", "DEU", "USA"),
